#!/usr/bin/env python
# -*- coding: utf-8 -*-

""" A package of reinforcement learning.
"""

from __future__ import with_statement, absolute_import


__author__ = 'Ming-Fan Li <li_m_f@163.com>'
__version__ = '0.0.1'

